@@ -76,9 +76,9 @@ static const char sccsid[] = "@(#)ant.c	5.24 2007/01/18 xlockmore";
 
 #ifdef MODE_ant
 
+#define DEF_LABEL "True"
 #define FONT_HEIGHT 19
 #define FONT_WIDTH 15
-#define DEF_LABEL "True"
 
 /*-
  * neighbors of 0 randomizes it for 3, 4, 6, 8, 12 (last 2 are less likely)
@@ -278,207 +278,207 @@ static unsigned char tables[][3 * NUMSTIPPLES * STATES + 2] =
 static void
 position_of_neighbor(antfarmstruct * ap, int dir, int *pcol, int *prow)
 {
-	int         col = *pcol, row = *prow;
+	int col = *pcol, row = *prow;
 
 	if (ap->neighbors == 4 || ap->neighbors == 6 || ap->neighbors == 8) {
 		switch (dir) {
-			case 0:
+		case 0:
+			col = (col + 1 == ap->ncols) ? 0 : col + 1;
+			break;
+		case 45:
+			col = (col + 1 == ap->ncols) ? 0 : col + 1;
+			row = (!row) ? ap->nrows - 1 : row - 1;
+			break;
+		case 60:
+			if (!(row & 1))
 				col = (col + 1 == ap->ncols) ? 0 : col + 1;
-				break;
-			case 45:
+			row = (!row) ? ap->nrows - 1 : row - 1;
+			break;
+		case 90:
+			row = (!row) ? ap->nrows - 1 : row - 1;
+			break;
+		case 120:
+			if (row & 1)
+				col = (!col) ? ap->ncols - 1 : col - 1;
+			row = (!row) ? ap->nrows - 1 : row - 1;
+			break;
+		case 135:
+			col = (!col) ? ap->ncols - 1 : col - 1;
+			row = (!row) ? ap->nrows - 1 : row - 1;
+			break;
+		case 180:
+			col = (!col) ? ap->ncols - 1 : col - 1;
+			break;
+		case 225:
+			col = (!col) ? ap->ncols - 1 : col - 1;
+			row = (row + 1 == ap->nrows) ? 0 : row + 1;
+			break;
+		case 240:
+			if (row & 1)
+				col = (!col) ? ap->ncols - 1 : col - 1;
+			row = (row + 1 == ap->nrows) ? 0 : row + 1;
+			break;
+		case 270:
+			row = (row + 1 == ap->nrows) ? 0 : row + 1;
+			break;
+		case 300:
+			if (!(row & 1))
 				col = (col + 1 == ap->ncols) ? 0 : col + 1;
-				row = (!row) ? ap->nrows - 1 : row - 1;
-				break;
-			case 60:
-				if (!(row & 1))
-					col = (col + 1 == ap->ncols) ? 0 : col + 1;
-				row = (!row) ? ap->nrows - 1 : row - 1;
-				break;
-			case 90:
-				row = (!row) ? ap->nrows - 1 : row - 1;
-				break;
-			case 120:
-				if (row & 1)
-					col = (!col) ? ap->ncols - 1 : col - 1;
-				row = (!row) ? ap->nrows - 1 : row - 1;
-				break;
-			case 135:
-				col = (!col) ? ap->ncols - 1 : col - 1;
-				row = (!row) ? ap->nrows - 1 : row - 1;
-				break;
-			case 180:
-				col = (!col) ? ap->ncols - 1 : col - 1;
-				break;
-			case 225:
-				col = (!col) ? ap->ncols - 1 : col - 1;
-				row = (row + 1 == ap->nrows) ? 0 : row + 1;
-				break;
-			case 240:
-				if (row & 1)
-					col = (!col) ? ap->ncols - 1 : col - 1;
-				row = (row + 1 == ap->nrows) ? 0 : row + 1;
-				break;
-			case 270:
-				row = (row + 1 == ap->nrows) ? 0 : row + 1;
-				break;
-			case 300:
-				if (!(row & 1))
-					col = (col + 1 == ap->ncols) ? 0 : col + 1;
-				row = (row + 1 == ap->nrows) ? 0 : row + 1;
-				break;
-			case 315:
-				col = (col + 1 == ap->ncols) ? 0 : col + 1;
-				row = (row + 1 == ap->nrows) ? 0 : row + 1;
-				break;
-			default:
-				(void) fprintf(stderr, "wrong direction %d\n", dir);
+			row = (row + 1 == ap->nrows) ? 0 : row + 1;
+			break;
+		case 315:
+			col = (col + 1 == ap->ncols) ? 0 : col + 1;
+			row = (row + 1 == ap->nrows) ? 0 : row + 1;
+			break;
+		default:
+			(void) fprintf(stderr, "wrong direction %d\n", dir);
 		}
 	} else {		/* TRI */
 		if ((col + row) % 2) {	/* right */
 			switch (dir) {
-				case 0:
-					col = (!col) ? ap->ncols - 1 : col - 1;
-					break;
-				case 30:
-				case 40:
-					col = (!col) ? ap->ncols - 1 : col - 1;
-					row = (!row) ? ap->nrows - 1 : row - 1;
-					break;
-				case 60:
-					col = (!col) ? ap->ncols - 1 : col - 1;
-					if (!row)
-						row = ap->nrows - 2;
-					else if (!(row - 1))
-						row = ap->nrows - 1;
-					else
-						row = row - 2;
-					break;
-				case 80:
-				case 90:
-					if (!row)
-						row = ap->nrows - 2;
-					else if (!(row - 1))
-						row = ap->nrows - 1;
-					else
-						row = row - 2;
-					break;
-				case 120:
-					row = (!row) ? ap->nrows - 1 : row - 1;
-					break;
-				case 150:
-				case 160:
-					col = (col + 1 == ap->ncols) ? 0 : col + 1;
-					row = (!row) ? ap->nrows - 1 : row - 1;
-					break;
-				case 180:
-					col = (col + 1 == ap->ncols) ? 0 : col + 1;
-					break;
-				case 200:
-				case 210:
-					col = (col + 1 == ap->ncols) ? 0 : col + 1;
-					row = (row + 1 == ap->nrows) ? 0 : row + 1;
-					break;
-				case 240:
-					row = (row + 1 == ap->nrows) ? 0 : row + 1;
-					break;
-				case 270:
-				case 280:
-					if (row + 1 == ap->nrows)
-						row = 1;
-					else if (row + 2 == ap->nrows)
-						row = 0;
-					else
-						row = row + 2;
-					break;
-				case 300:
-					col = (!col) ? ap->ncols - 1 : col - 1;
-					if (row + 1 == ap->nrows)
-						row = 1;
-					else if (row + 2 == ap->nrows)
-						row = 0;
-					else
-						row = row + 2;
-					break;
-				case 320:
-				case 330:
-					col = (!col) ? ap->ncols - 1 : col - 1;
-					row = (row + 1 == ap->nrows) ? 0 : row + 1;
-					break;
-				default:
-					(void) fprintf(stderr, "wrong direction %d\n", dir);
+			case 0:
+				col = (!col) ? ap->ncols - 1 : col - 1;
+				break;
+			case 30:
+			case 40:
+				col = (!col) ? ap->ncols - 1 : col - 1;
+				row = (!row) ? ap->nrows - 1 : row - 1;
+				break;
+			case 60:
+				col = (!col) ? ap->ncols - 1 : col - 1;
+				if (!row)
+					row = ap->nrows - 2;
+				else if (!(row - 1))
+					row = ap->nrows - 1;
+				else
+					row = row - 2;
+				break;
+			case 80:
+			case 90:
+				if (!row)
+					row = ap->nrows - 2;
+				else if (!(row - 1))
+					row = ap->nrows - 1;
+				else
+					row = row - 2;
+				break;
+			case 120:
+				row = (!row) ? ap->nrows - 1 : row - 1;
+				break;
+			case 150:
+			case 160:
+				col = (col + 1 == ap->ncols) ? 0 : col + 1;
+				row = (!row) ? ap->nrows - 1 : row - 1;
+				break;
+			case 180:
+				col = (col + 1 == ap->ncols) ? 0 : col + 1;
+				break;
+			case 200:
+			case 210:
+				col = (col + 1 == ap->ncols) ? 0 : col + 1;
+				row = (row + 1 == ap->nrows) ? 0 : row + 1;
+				break;
+			case 240:
+				row = (row + 1 == ap->nrows) ? 0 : row + 1;
+				break;
+			case 270:
+			case 280:
+				if (row + 1 == ap->nrows)
+					row = 1;
+				else if (row + 2 == ap->nrows)
+					row = 0;
+				else
+					row = row + 2;
+				break;
+			case 300:
+				col = (!col) ? ap->ncols - 1 : col - 1;
+				if (row + 1 == ap->nrows)
+					row = 1;
+				else if (row + 2 == ap->nrows)
+					row = 0;
+				else
+					row = row + 2;
+				break;
+			case 320:
+			case 330:
+				col = (!col) ? ap->ncols - 1 : col - 1;
+				row = (row + 1 == ap->nrows) ? 0 : row + 1;
+				break;
+			default:
+				(void) fprintf(stderr, "wrong direction %d\n", dir);
 			}
 		} else {	/* left */
 			switch (dir) {
-				case 0:
-					col = (col + 1 == ap->ncols) ? 0 : col + 1;
-					break;
-				case 30:
-				case 40:
-					col = (col + 1 == ap->ncols) ? 0 : col + 1;
-					row = (row + 1 == ap->nrows) ? 0 : row + 1;
-					break;
-				case 60:
-					col = (col + 1 == ap->ncols) ? 0 : col + 1;
-					if (row + 1 == ap->nrows)
-						row = 1;
-					else if (row + 2 == ap->nrows)
-						row = 0;
-					else
-						row = row + 2;
-					break;
-				case 80:
-				case 90:
-					if (row + 1 == ap->nrows)
-						row = 1;
-					else if (row + 2 == ap->nrows)
-						row = 0;
-					else
-						row = row + 2;
-					break;
-				case 120:
-					row = (row + 1 == ap->nrows) ? 0 : row + 1;
-					break;
-				case 150:
-				case 160:
-					col = (!col) ? ap->ncols - 1 : col - 1;
-					row = (row + 1 == ap->nrows) ? 0 : row + 1;
-					break;
-				case 180:
-					col = (!col) ? ap->ncols - 1 : col - 1;
-					break;
-				case 200:
-				case 210:
-					col = (!col) ? ap->ncols - 1 : col - 1;
-					row = (!row) ? ap->nrows - 1 : row - 1;
-					break;
-				case 240:
-					row = (!row) ? ap->nrows - 1 : row - 1;
-					break;
-				case 270:
-				case 280:
-					if (!row)
-						row = ap->nrows - 2;
-					else if (row == 1)
-						row = ap->nrows - 1;
-					else
-						row = row - 2;
-					break;
-				case 300:
-					col = (col + 1 == ap->ncols) ? 0 : col + 1;
-					if (!row)
-						row = ap->nrows - 2;
-					else if (row == 1)
-						row = ap->nrows - 1;
-					else
-						row = row - 2;
-					break;
-				case 320:
-				case 330:
-					col = (col + 1 == ap->ncols) ? 0 : col + 1;
-					row = (!row) ? ap->nrows - 1 : row - 1;
-					break;
-				default:
-					(void) fprintf(stderr, "wrong direction %d\n", dir);
+			case 0:
+				col = (col + 1 == ap->ncols) ? 0 : col + 1;
+				break;
+			case 30:
+			case 40:
+				col = (col + 1 == ap->ncols) ? 0 : col + 1;
+				row = (row + 1 == ap->nrows) ? 0 : row + 1;
+				break;
+			case 60:
+				col = (col + 1 == ap->ncols) ? 0 : col + 1;
+				if (row + 1 == ap->nrows)
+					row = 1;
+				else if (row + 2 == ap->nrows)
+					row = 0;
+				else
+					row = row + 2;
+				break;
+			case 80:
+			case 90:
+				if (row + 1 == ap->nrows)
+					row = 1;
+				else if (row + 2 == ap->nrows)
+					row = 0;
+				else
+					row = row + 2;
+				break;
+			case 120:
+				row = (row + 1 == ap->nrows) ? 0 : row + 1;
+				break;
+			case 150:
+			case 160:
+				col = (!col) ? ap->ncols - 1 : col - 1;
+				row = (row + 1 == ap->nrows) ? 0 : row + 1;
+				break;
+			case 180:
+				col = (!col) ? ap->ncols - 1 : col - 1;
+				break;
+			case 200:
+			case 210:
+				col = (!col) ? ap->ncols - 1 : col - 1;
+				row = (!row) ? ap->nrows - 1 : row - 1;
+				break;
+			case 240:
+				row = (!row) ? ap->nrows - 1 : row - 1;
+				break;
+			case 270:
+			case 280:
+				if (!row)
+					row = ap->nrows - 2;
+				else if (row == 1)
+					row = ap->nrows - 1;
+				else
+					row = row - 2;
+				break;
+			case 300:
+				col = (col + 1 == ap->ncols) ? 0 : col + 1;
+				if (!row)
+					row = ap->nrows - 2;
+				else if (row == 1)
+					row = ap->nrows - 1;
+				else
+					row = row - 2;
+				break;
+			case 320:
+			case 330:
+				col = (col + 1 == ap->ncols) ? 0 : col + 1;
+				row = (!row) ? ap->nrows - 1 : row - 1;
+				break;
+			default:
+				(void) fprintf(stderr, "wrong direction %d\n", dir);
 			}
 		}
 	}
@@ -577,7 +577,7 @@ truchetcell(ModeInfo * mi, int col, int row, int truchetstate)
 						hex.x += ap->shape.hexagon[side].y;
 					}
 				}
-				if (truchetstate == side % 2)
+				if (truchetstate == side % 2) {
 					if (ap->vertical) {
 					    XDrawArc(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
 						hex.x, hex.y, ap->xs, ap->ys,
@@ -589,6 +589,7 @@ truchetcell(ModeInfo * mi, int col, int row, int truchetstate)
 						((300 + (side * 60) + fudge) % 360) * 64,
 						(120 - 2 * fudge) * 64);
 					}
+				}
 			}
 		} else {
 			/* Very crude approx of Sqrt 3, so it will not cause drawing errors. */
@@ -629,7 +630,7 @@ truchetcell(ModeInfo * mi, int col, int row, int truchetstate)
 					hex2.x += (short) (ap->xs * 0.5);
 					hex2.y += (short) (-ap->ys * 0.3);
 				}
-				if (truchetstate == side % 3)
+				if (truchetstate == side % 3) {
 					/* Crude approx of 120 deg, so it will not cause drawing errors. */
 					if (ap->vertical) {
 					    XDrawArc(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
@@ -642,6 +643,7 @@ truchetcell(ModeInfo * mi, int col, int row, int truchetstate)
 						 (int) ((double) ap->ys * 1.5), (int) ((double) ap->xs * 1.5),
 						 ((345 + (side * 60)) % 360) * 64, 90 * 64);
 					}
+				}
 			}
 		}
 	} else if (ap->neighbors == 4) {
@@ -1033,7 +1035,8 @@ static void
 getTurk(ModeInfo * mi, int logClass, int number)
 {
 	antfarmstruct *ap = &antfarms[MI_SCREEN(mi)];
-	int         power2, j, total;
+	int power2, j, total;
+	char rule[NUMSTIPPLES * STATES + 1];
 
 	power2 = 1 << (logClass - 1);
 	ap->ncolors = logClass;
@@ -1050,15 +1053,17 @@ getTurk(ModeInfo * mi, int logClass, int number)
 				fromTableDirection(TRS, ap->neighbors) :
 				fromTableDirection(TLS, ap->neighbors);
 		}
+		rule[j] = ((power2 & number) ? 1 : 0) + '0';
 		ap->machine[j].next = 0;
 		power2 >>= 1;
 	}
+	rule[total] = '\0';
 	ap->truchet = (ap->truchet && ap->xs > 2 && ap->ys > 2 &&
 	   (ap->neighbors == 3 || ap->neighbors == 4 || ap->neighbors == 6));
 	if (MI_IS_VERBOSE(mi))
 		(void) fprintf(stdout,
-			"ants %d, neighbors %d, Turk's number 0x%x, colors %d\n",
-			ap->n, ap->neighbors, number, ap->ncolors);
+			"ants %d, neighbors %d, Turk's number 0x%x (%s), colors %d\n",
+			ap->n, ap->neighbors, number, rule, ap->ncolors);
 	if (label)
 		(void) sprintf(ap->ruleString, "%d Turk's number 0x%x",
 			ap->n, number);
@@ -1353,8 +1358,8 @@ init_ant(ModeInfo * mi)
 
 		for (i = 0; i < (int) ap->ncolors - 1; i++) {
 			ap->colors[i] = (unsigned char) ((offset +
-				(i * MI_NPIXELS(mi) / (int) (ap->ncolors - 1))) %
-				MI_NPIXELS(mi));
+				(i * MI_NPIXELS(mi) /
+				(int) (ap->ncolors - 1))) % MI_NPIXELS(mi));
 		}
 	}
 	if (ap->ants == NULL) {
